pub struct CaughtException {
pub exception_object: Value,
pub exception_class_name: String,
pub message: String,
}Expand description
Wraps a Ruby exception Value and exposes its values usable in Rust.
Fields
exception_object: Valueexception_class_name: Stringmessage: StringTrait Implementations
Sourceimpl Debug for CaughtException
impl Debug for CaughtException
Sourceimpl Display for CaughtException
Formats the exception like <ClassName>: <message>
impl Display for CaughtException
Formats the exception like <ClassName>: <message>
Sourceimpl Error for CaughtException
impl Error for CaughtException
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl PartialEq for CaughtException
Compare the class and message of an exception against another.
impl PartialEq for CaughtException
Compare the class and message of an exception against another.
impl Eq for CaughtException