Value

Struct Value 

#[repr(transparent)]
pub struct Value(pub VALUE);
Wraps a plain old Ruby FFI VALUE with much more functionality.

Tuple Fields

0: VALUE

Implementations

Source

impl Value

pub const NIL: Self

The Ruby nil value.

pub const TRUE: Self

The Ruby true value.

pub const FALSE: Self

The Ruby false value.

pub fn send( &self, method_name: &str, arguments: &[Value], ) -> Result<Value, CaughtException>

Sends a Ruby method and returns the result.

pub unsafe fn send_unprotected( &self, method_name: &str, arguments: &[Value], ) -> Value

Sends a Ruby method without rescuing Ruby unwind.

pub fn constant(&self, constant_name: &str) -> Result<Value, CaughtException>

Gets a constant by name. Equivalent to Object#const_get(constant_name).

pub unsafe fn constant_unprotected(&self, constant_name: &str) -> Value

Gets a constant by name. Equivalent to Object#const_get(constant_name).

pub fn set_constant( &self, constant_name: &str, value: Value, ) -> Result<(), CaughtException>

Sets a constant. Equivalent to Object#const_set(constant_name, value).

pub unsafe fn set_constant_unprotected(&self, constant_name: &str, value: Value)

Sets a constant. Equivalent to Object#const_set(constant_name, value).

pub fn to_s(&self) -> Result<String, CaughtException>

Convert a Ruby value to a Rust string.

Calls Object#to_s and then converts the result to a string.

pub unsafe fn to_s_unprotected(&self) -> String

Convert a Ruby value to a Rust string.

pub fn object_class_name(&self) -> String

Convert a Ruby string to a Rust string. Gets the class name for an object

pub fn inspect(&self) -> Result<Value, CaughtException>

Calls Object#inspect

pub unsafe fn inspect_unprotected(&self) -> Value

Calls Object#inspect

pub fn is_of_value_type(&self, value_type: value_type) -> bool

Checks if this object is of the given value type.

pub fn is_nil(&self) -> bool

Checks if this value is nil.

pub fn convert_array(values: &[Value]) -> &[VALUE]